@@ -1,7 +1,7 @@
 package App::DuckPAN;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: The DuckDuckGo DuckPAN client
-$App::DuckPAN::VERSION = '0.189';
+$App::DuckPAN::VERSION = '0.190';
 use feature 'state';
 
 use Moo;
@@ -29,6 +29,13 @@ use App::DuckPAN::Cmd::Help;
 
 no warnings 'uninitialized';
 
+option dukgo_my_account => (
+	is => 'ro',
+	lazy => 1,
+	default => sub { 'https://duck.co/my/account' },
+	doc => 'Account page URI - you need to be authed to get HTTP 200',
+);
+
 option dukgo_login => (
 	is => 'ro',
 	lazy => 1,
@@ -590,11 +597,10 @@ sub check_ia_bundles {
 
 sub checking_dukgo_user {
 	my ( $self, $user, $pass ) = @_;
-	my $response = $self->http->request(POST($self->dukgo_login, Content => {
-		username => $user,
-		password => $pass,
-	}));
-	$response->code == 302 ? 1 : 0; # workaround, need something in dukgo
+	my $request = GET( $self->dukgo_my_account );
+	$request->authorization_basic( $user, $pass );
+	my $response = $self->http->request( $request );
+	return ( $response->code == 200 );
 }
 
 sub get_ia_type {
@@ -641,7 +647,7 @@ App::DuckPAN - The DuckDuckGo DuckPAN client
 
 =head1 VERSION
 
-version 0.189
+version 0.190
 
 =head1 DuckPAN
 
